{% load i18n %}
{% load crispy_forms_tags %}

<form action="{% url 'chimps_subscribe' %}" method="POST">
    {% csrf_token %}
    {{ form|crispy }}
    <div class="form-group">
        <input type="submit" value="{% trans "Subscribe" %}" class="btn btn-primary">
    </div>
</form>
